@@ -36,7 +36,6 @@ public:
         BadgeLabelBackgroundColorUnchecked,
         BadgeLabelTextColorChecked,
         BadgeLabelTextColorUnchecked,
-        CanceledSearchTextColor,
         ComboBoxArrowColor,
         ComboBoxArrowColorDisabled,
         ComboBoxTextColor,
@@ -224,17 +223,34 @@ public:
         Debugger_WatchItem_ValueInvalid,
         Debugger_WatchItem_ValueChanged,
 
-        /* Welcome Plugin */
+        /* Qt Creator Color Tokens */
 
-        Welcome_TextColor,
-        Welcome_ForegroundPrimaryColor,
-        Welcome_ForegroundSecondaryColor,
-        Welcome_BackgroundPrimaryColor,
-        Welcome_BackgroundSecondaryColor,
-        Welcome_HoverColor,
-        Welcome_AccentColor,
-        Welcome_LinkColor,
-        Welcome_DisabledLinkColor,
+        Token_Basic_Black,
+        Token_Basic_White,
+        Token_Accent_Default,
+        Token_Accent_Muted,
+        Token_Accent_Subtle,
+        Token_Background_Default,
+        Token_Background_Muted,
+        Token_Background_Subtle,
+        Token_Foreground_Default,
+        Token_Foreground_Muted,
+        Token_Foreground_Subtle,
+        Token_Text_Default,
+        Token_Text_Muted,
+        Token_Text_Subtle,
+        Token_Text_Accent,
+        Token_Stroke_Strong,
+        Token_Stroke_Muted,
+        Token_Stroke_Subtle,
+        Token_Notification_Alert,
+        Token_Notification_Success,
+        Token_Notification_Neutral,
+        Token_Notification_Danger,
+        Token_Gradient01_Start,
+        Token_Gradient01_End,
+        Token_Gradient02_Start,
+        Token_Gradient02_End,
 
         /* Timeline Library */
         Timeline_TextColor,
@@ -260,6 +276,7 @@ public:
 
         /* TextEditor Plugin */
         TextEditor_SearchResult_ScrollBarColor,
+        TextEditor_Selection_ScrollBarColor,
         TextEditor_CurrentLine_ScrollBarColor,
 
         /* Debugger Plugin */
@@ -285,7 +302,6 @@ public:
         QmlDesigner_ScrollBarHandleColor,
 
         /* Palette for DS Controls */
-
         DSpanelBackground,
         DSinteraction,
         DSerrorColor,
@@ -305,9 +321,63 @@ public:
         DStextSelectionColor,
         DStextSelectedTextColor,
 
+        /*NEW for QtDS 4.0*/
+        DScontrolBackground_toolbarIdle,
+        DScontrolBackground_toolbarHover,
+        DStoolbarBackground,
+        DStoolbarIcon_blocked,
+        DSthumbnailBackground_baseState,
+        DSidleGreen,
+        DSrunningGreen,
+        DSstatusbarBackground,
+        DScontrolBackground_statusbarIdle,
+        DScontrolBackground_topToolbarHover,
+        DSControlBackground_statusbarHover,
+        DScontrolOutline_topToolbarIdle,
+        DScontrolOutline_topToolbarHover,
+        DSprimaryButton_hoverHighlight,
+        DSstateBackgroundColor_hover,
+        DSstateControlBackgroundColor_hover,
+        DSstateControlBackgroundColor_globalHover,
         DSplaceholderTextColor,
         DSplaceholderTextColorInteraction,
+        DSpopoutBackground,
+        DSpopoutControlBackground_idle,
+        DSpopoutControlBackground_hover,
+        DSpopoutControlBackground_globalHover,
+        DSpopoutControlBackground_interaction,
+        DSpopoutControlBackground_disabled,
+        DSpopoutPopupBackground,
+        DSpopoutControlBorder_idle,
+        DSpopoutControlBorder_hover,
+        DSpopoutControlBorder_interaction,
+        DSpopoutControlBorder_disabled,
+        DSpopoutButtonBackground_idle,
+        DSpopoutButtonBackground_hover,
+        DSpopoutButtonBackground_interaction,
+        DSpopoutButtonBackground_disabled,
+        DSpopoutButtonBorder_idle,
+        DSpopoutButtonBorder_hover,
+        DSpopoutButtonBorder_interaction,
+        DSpopoutButtonBorder_disabled,
+        DSscrollBarTrack,
+        DSscrollBarHandle,
+        DSscrollBarHandle_idle,
+        DSconnectionCodeEditor,
+        DSpillText,
+        DSpillTextSelected,
+        DspillTextEdit,
+        DSpillDefaultBackgroundIdle,
+        DSpillDefaultBackgroundHover,
+        DSpillOperatorBackgroundIdle,
+        DSpillOperatorBackgroundHover,
+        DSpillLiteralBackgroundIdle,
+        DSpillLiteralBackgroundHover,
+        DSconnectionEditorMicroToolbar,
+        DSconnectionEditorButtonBackground_hover,
+        DSconnectionEditorButtonBorder_hover,
 
+        /*Legacy QtDS*/
         DSiconColor,
         DSiconColorHover,
         DSiconColorInteraction,
@@ -329,8 +399,6 @@ public:
         DSsliderHandleHover,
         DSsliderHandleFocus,
         DSsliderHandleInteraction,
-        DSscrollBarTrack,
-        DSscrollBarHandle,
         DSsectionHeadBackground,
         DSstateDefaultHighlight,
         DSstateSeparatorColor,
@@ -420,6 +488,28 @@ public:
 
         DSstatePanelBackground,
         DSstateHighlight,
+
+        TerminalForeground,
+        TerminalBackground,
+        TerminalSelection,
+        TerminalFindMatch,
+
+        TerminalAnsi0,
+        TerminalAnsi1,
+        TerminalAnsi2,
+        TerminalAnsi3,
+        TerminalAnsi4,
+        TerminalAnsi5,
+        TerminalAnsi6,
+        TerminalAnsi7,
+        TerminalAnsi8,
+        TerminalAnsi9,
+        TerminalAnsi10,
+        TerminalAnsi11,
+        TerminalAnsi12,
+        TerminalAnsi13,
+        TerminalAnsi14,
+        TerminalAnsi15,
     };
 
     enum ImageFile {
@@ -441,14 +531,15 @@ public:
         DrawToolBarBorders,
         ComboBoxDrawTextShadow,
         DerivePaletteFromTheme,
-        ApplyThemePaletteGlobally,
+        DerivePaletteFromThemeIfNeeded,
         FlatToolBars,
         FlatSideBarIcons,
         FlatProjectsMode,
         FlatMenuBar,
         ToolBarIconShadow,
         WindowColorAsBase,
-        DarkUserInterface
+        DarkUserInterface,
+        QDSTheme
     };
 
     Q_ENUM(Color)
@@ -481,12 +572,15 @@ protected:
     ThemePrivate *d;
 
 private:
+    void readSettingsInternal(QSettings &settings);
     friend QTCREATOR_UTILS_EXPORT Theme *creatorTheme();
     friend QTCREATOR_UTILS_EXPORT Theme *proxyTheme();
+    QColor readNamedColorNoWarning(const QString &color) const;
     QPair<QColor, QString> readNamedColor(const QString &color) const;
 };
 
 QTCREATOR_UTILS_EXPORT Theme *creatorTheme();
 QTCREATOR_UTILS_EXPORT Theme *proxyTheme();
+QTCREATOR_UTILS_EXPORT QColor creatorColor(Theme::Color role);
 
 } // namespace Utils
